# Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1] - 2024-11-27

### Added

- `update_collection_extents` ([#17](https://github.com/stac-utils/pgstacrs/pull/17))

## [0.1.0] - 2024-11-27

Initial release.

[Unreleased]: https://github.com/gadomski/stacrs/compare/v0.1.1...main
[0.1.1]: https://github.com/gadomski/stacrs/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/stac-utils/stac-rs/releases/tag/v0.1.0

<!-- markdownlint-disable-file MD024 -->
